@@ -1,7 +1,7 @@
 #' @importFrom xml2 read_html
 #' @importFrom R.utils withTimeout
 get_html <- function(page){
-  if(class(page) == 'response') {
+  if(class(page) %in% c('response', 'character')) {
     html_out <- try(
       withTimeout(xml2::read_html(page), 
                   onTimeout = 'error', 
